@@ -1,14 +1,27 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/**
- * eog-collection-view.c
- *
- * Authors:
- *   Martin Baulig (baulig@suse.de)
- *   Jens Finke (jens@gnome.org)
+/* Eog Of Gnome - view of the image collection
  *
  * Copyright 2000 SuSE GmbH.
- * Copyright 2001 The Free Software Foundation
+ * Copyright 2001-2003 The Free Software Foundation
+ *
+ * Author: Jens Finke <jens@gnome.org>
+ *
+ * Based on code by: Martin Baulig <baulig@suse.de>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
 #include <config.h>
 #include <stdio.h>
 #include <gtk/gtksignal.h>
@@ -16,33 +29,29 @@
 #include <gtk/gtktypeutils.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkwindow.h>
+#include <gtk/gtkpaned.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-result.h>
 #include <libgnomevfs/gnome-vfs-find-directory.h>
 #include <libgnomeui/gnome-dialog-util.h>
+#include <libgnome/gnome-i18n.h>
 #include <gconf/gconf-client.h>
 #include <bonobo/bonobo-macros.h>
 #include <bonobo/bonobo-persist-file.h>
+#include <bonobo/bonobo-control.h>
+#include <bonobo/bonobo-property-bag.h>
+#include <bonobo/bonobo-zoomable.h>
+#include <bonobo/bonobo-ui-util.h>
 
-#ifdef ENABLE_EVOLUTION
-#  include "Evolution-Composer.h"
-#endif
-
-#if HAVE_LIBPREVIEW
-#include "eog-image-loader-preview.h"
-#else
-#include "eog-image-loader-simple.h"
-#endif
-
-#include "eog-item-factory-clean.h"
 #include "eog-wrap-list.h"
+#include "eog-scroll-view.h"
 #include "eog-collection-view.h"
 #include "eog-collection-model.h"
-#include "eog-collection-preferences.h"
 #include "eog-collection-marshal.h"
-#include "eog-slide-show.h"
+#include "eog-full-screen.h"
+#include "eog-info-view.h"
 
 enum {
 	PROP_WINDOW_TITLE,
@@ -71,9 +80,11 @@ struct _EogCollectionViewPrivate {
 	EogCollectionModel      *model;
 
 	GtkWidget               *wraplist;
-	GtkWidget               *root;
+	GtkWidget               *scroll_view;
+	GtkWidget               *info_view;
 
 	BonoboPropertyBag       *property_bag;
+	BonoboZoomable          *zoomable;
 
 	BonoboUIComponent       *uic;
 
@@ -82,6 +93,10 @@ struct _EogCollectionViewPrivate {
 
 	gint                    idle_id;
 	gboolean                need_update_prop[PROP_LAST];
+
+	EogImage                *displayed_image;
+
+	gboolean                has_zoomable_frame;
 };
 
 
@@ -92,57 +107,9 @@ enum {
 
 static guint eog_collection_view_signals [LAST_SIGNAL];
 
-static void eog_collection_view_dispose (GObject *object);
+BONOBO_CLASS_BOILERPLATE (EogCollectionView, eog_collection_view,
+			  BonoboPersistFile, BONOBO_TYPE_PERSIST_FILE);
 
-BONOBO_CLASS_BOILERPLATE_FULL (EogCollectionView, eog_collection_view,
-			       GNOME_EOG_ImageCollection,
-			       BonoboObject, BONOBO_TYPE_OBJECT);
-
-
-static void 
-impl_GNOME_EOG_ImageCollection_openURI (PortableServer_Servant servant,
-					const CORBA_char * uri,
-					CORBA_Environment * ev)
-{
-	EogCollectionView *cview;
-	EogCollectionViewPrivate *priv;
-
-	cview = EOG_COLLECTION_VIEW (bonobo_object_from_servant (servant));
-	priv = cview->priv;
-
-	if (uri == CORBA_OBJECT_NIL) return;
-
-	eog_collection_model_set_uri (priv->model, (gchar*)uri); 
-}
-
-
-static void 
-impl_GNOME_EOG_ImageCollection_openURIList (PortableServer_Servant servant,
-					    const GNOME_EOG_URIList *uri_list,
-					    CORBA_Environment * ev)
-{
-	EogCollectionView *cview;
-	EogCollectionViewPrivate *priv;
-        GList *list;
-        guint i;
-
-	cview = EOG_COLLECTION_VIEW (bonobo_object_from_servant (servant));
-	priv = cview->priv;
-	
-        list = NULL;
-#ifdef COLLECTION_DEBUG
-	g_print ("uri_list->_length: %i\n", uri_list->_length);
-#endif
-        for (i = 0; i < uri_list->_length; i++) {
-                list = g_list_append
-                        (list, g_strdup (uri_list->_buffer[i]));
-        }
-        
-	eog_collection_model_set_uri_list (priv->model, list);
-
-	g_list_foreach (list, (GFunc) g_free, NULL);
-	g_list_free (list);
-}
 
 static void
 verb_SlideShow_cb (BonoboUIComponent *uic, 
@@ -151,34 +118,145 @@ verb_SlideShow_cb (BonoboUIComponent *uic,
 {
 	EogCollectionView *view;
 	GtkWidget *show;
+	GList *images = NULL;
+	EogImage *start_image = NULL;
+	gboolean free_list = FALSE;
 
 	view = EOG_COLLECTION_VIEW (user_data);
 
-	show = eog_slide_show_new (view->priv->model);
+	if (eog_wrap_list_get_n_selected (EOG_WRAP_LIST (view->priv->wraplist)) > 1) {
+		images = eog_wrap_list_get_selected_images (EOG_WRAP_LIST (view->priv->wraplist));
+		free_list = TRUE;
+	}
+	else {
+		images = eog_collection_model_get_image_list (view->priv->model);
+	}
+	start_image = eog_wrap_list_get_first_selected_image (EOG_WRAP_LIST (view->priv->wraplist));
+
+	show = eog_full_screen_new (images, start_image);
+	g_object_unref (start_image);
+
+	if (free_list)
+		g_list_free (images);
+
 	gtk_widget_show (show);
 }
 
+static void
+verb_ImagePrev_cb (BonoboUIComponent *uic,
+		   gpointer user_data,
+		   const char *cname)
+{
+	EogCollectionView *view;
+	
+	view = EOG_COLLECTION_VIEW (user_data);
+
+	eog_wrap_list_select_left (EOG_WRAP_LIST (view->priv->wraplist));
+}
+
+static void
+verb_ImageNext_cb (BonoboUIComponent *uic,
+		   gpointer user_data,
+		   const char *cname)
+{
+	EogCollectionView *view;
+	
+	view = EOG_COLLECTION_VIEW (user_data);
+
+	eog_wrap_list_select_right (EOG_WRAP_LIST (view->priv->wraplist));
+}
+
+static void
+verb_ZoomIn_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
+{
+	EogCollectionView *view;
+
+	g_return_if_fail (EOG_IS_COLLECTION_VIEW (user_data));
+
+	view = EOG_COLLECTION_VIEW (user_data);
+
+	eog_scroll_view_zoom_in (EOG_SCROLL_VIEW (view->priv->scroll_view), FALSE);
+}
+
+static void
+verb_ZoomOut_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
+{
+	EogCollectionView *view;
+
+	g_return_if_fail (EOG_IS_COLLECTION_VIEW (user_data));
+
+	view = EOG_COLLECTION_VIEW (user_data);
+
+	eog_scroll_view_zoom_out (EOG_SCROLL_VIEW (view->priv->scroll_view), FALSE);
+}
+
+static void
+verb_ZoomToDefault_cb (BonoboUIComponent *uic, gpointer user_data,
+		       const char *cname)
+{
+	EogCollectionView *view;
+
+	g_return_if_fail (EOG_IS_COLLECTION_VIEW (user_data));
+
+	view = EOG_COLLECTION_VIEW (user_data);
+
+	eog_scroll_view_set_zoom (EOG_SCROLL_VIEW (view->priv->scroll_view), 1.0);
+}
+
+static void
+verb_ZoomToFit_cb (BonoboUIComponent *uic, gpointer user_data,
+		   const char *cname)
+{
+	EogCollectionView *view;
+
+	g_return_if_fail (EOG_IS_COLLECTION_VIEW (user_data));
+
+	view = EOG_COLLECTION_VIEW (user_data);
+
+	eog_scroll_view_zoom_fit (EOG_SCROLL_VIEW (view->priv->scroll_view));
+}
+
+static BonoboUIVerb eog_zoom_verbs[] = {
+	BONOBO_UI_VERB ("ZoomIn",        verb_ZoomIn_cb),
+	BONOBO_UI_VERB ("ZoomOut",       verb_ZoomOut_cb),
+	BONOBO_UI_VERB ("ZoomToDefault", verb_ZoomToDefault_cb),
+	BONOBO_UI_VERB ("ZoomToFit",     verb_ZoomToFit_cb),
+	BONOBO_UI_VERB_END
+};
 
 static BonoboUIVerb collection_verbs[] = {
 	BONOBO_UI_VERB ("SlideShow", verb_SlideShow_cb),
+	BONOBO_UI_VERB ("ImageNext", verb_ImageNext_cb),
+	BONOBO_UI_VERB ("ImagePrev", verb_ImagePrev_cb),
 	BONOBO_UI_VERB_END
 };
 
 static void
 eog_collection_view_create_ui (EogCollectionView *view)
 {
+	EogCollectionViewPrivate *priv;
+
 	g_return_if_fail (EOG_IS_COLLECTION_VIEW (view));
 
+	priv = view->priv;
+
 	/* Set up the UI from an XML file. */
-        bonobo_ui_util_set_ui (view->priv->uic, DATADIR,
+        bonobo_ui_util_set_ui (priv->uic, DATADIR,
 			       "eog-collection-view-ui.xml", "EogCollectionView", NULL);
 
-	bonobo_ui_component_add_verb_list_with_data (view->priv->uic,
+	bonobo_ui_component_add_verb_list_with_data (priv->uic,
 						     collection_verbs,
 						     view);
+
+	if (!priv->has_zoomable_frame) {
+		bonobo_ui_util_set_ui (priv->uic, DATADIR, "eog-image-view-ctrl-ui.xml", "EogCollectionView", NULL);
+		
+		bonobo_ui_component_add_verb_list_with_data (priv->uic, eog_zoom_verbs,
+							     view);
+	}
 }
 
-void
+static void
 eog_collection_view_set_ui_container (EogCollectionView      *list_view,
 				      Bonobo_UIContainer ui_container)
 {
@@ -191,7 +269,7 @@ eog_collection_view_set_ui_container (EogCollectionView      *list_view,
 	eog_collection_view_create_ui (list_view);
 }
 
-void
+static void
 eog_collection_view_unset_ui_container (EogCollectionView *list_view)
 {
 	g_return_if_fail (list_view != NULL);
@@ -200,26 +278,46 @@ eog_collection_view_unset_ui_container (EogCollectionView *list_view)
 	bonobo_ui_component_unset_container (list_view->priv->uic, NULL);
 }
 
-GtkWidget *
-eog_collection_view_get_widget (EogCollectionView *list_view)
+static void
+control_activate_cb (BonoboControl *object, gboolean state, gpointer data)
 {
-	g_return_val_if_fail (list_view != NULL, NULL);
-	g_return_val_if_fail (EOG_IS_COLLECTION_VIEW (list_view), NULL);
+	EogCollectionView *view;
 
-	gtk_widget_ref (list_view->priv->root);
+	g_return_if_fail (EOG_IS_COLLECTION_VIEW (data));
 
-	return list_view->priv->root;
+	view = EOG_COLLECTION_VIEW (data);
+
+	if (state) {
+		Bonobo_UIContainer ui_container;
+
+		ui_container = bonobo_control_get_remote_ui_container (object, NULL);
+		if (ui_container != CORBA_OBJECT_NIL) {
+			eog_collection_view_set_ui_container (view, ui_container);
+			bonobo_object_release_unref (ui_container, NULL);
+		}
+
+	} else
+		eog_collection_view_unset_ui_container (view);
 }
 
+
+
 static void
 eog_collection_view_dispose (GObject *object)
 {
 	EogCollectionView *list_view;
+	EogCollectionViewPrivate *priv;
 
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (EOG_IS_COLLECTION_VIEW (object));
 
 	list_view = EOG_COLLECTION_VIEW (object);
+	priv = list_view->priv;
+
+	if (priv->displayed_image != NULL) {
+		g_object_unref (priv->displayed_image);
+		priv->displayed_image = NULL;
+	}
 
 	if (list_view->priv->model)
 		g_object_unref (G_OBJECT (list_view->priv->model));
@@ -238,7 +336,7 @@ eog_collection_view_dispose (GObject *object)
 	list_view->priv->uic = NULL;
 
 	list_view->priv->wraplist = NULL;
-	list_view->priv->root = NULL;
+	list_view->priv->scroll_view = NULL;
 
 	BONOBO_CALL_PARENT (G_OBJECT_CLASS, dispose, (object));
 }
@@ -262,25 +360,9 @@ static void
 eog_collection_view_class_init (EogCollectionViewClass *klass)
 {
 	GObjectClass *object_class = (GObjectClass *)klass;
-	POA_GNOME_EOG_ImageCollection__epv *epv;
 
 	object_class->dispose = eog_collection_view_dispose;
 	object_class->finalize = eog_collection_view_finalize;
-
-	epv = &klass->epv;
-	epv->openURI = impl_GNOME_EOG_ImageCollection_openURI;
-	epv->openURIList = impl_GNOME_EOG_ImageCollection_openURIList;
-
-	eog_collection_view_signals [OPEN_URI] = 
-		g_signal_new ("open_uri",
-			      G_TYPE_FROM_CLASS(object_class),
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EogCollectionViewClass, open_uri),
-			      NULL,
-			      NULL,
-			      eog_collection_marshal_VOID__POINTER,
-			      G_TYPE_NONE, 1,
-			      G_TYPE_POINTER);
 }
 
 static void
@@ -288,183 +370,11 @@ eog_collection_view_instance_init (EogCollectionView *view)
 {
 	view->priv = g_new0 (EogCollectionViewPrivate, 1);
 	view->priv->idle_id = -1;
+	view->priv->model = NULL;
+
+	view->priv->displayed_image = NULL;
 }
 
-static void
-handle_double_click (EogWrapList *wlist, gint n, EogCollectionView *view)
-{
-	gchar *uri;
-
-	g_return_if_fail (EOG_IS_COLLECTION_VIEW (view));
-	
-	uri = eog_collection_model_get_uri (view->priv->model, n);
-	if (uri == NULL) return;
-
-	g_signal_emit (G_OBJECT (view), eog_collection_view_signals [OPEN_URI], 0, uri);
-
-	g_free (uri);
-}
-
-static gboolean
-delete_item (EogCollectionModel *model, CImage *image, gpointer user_data)
-{
-	GnomeVFSURI *uri, *trash = NULL, *path;
-	GnomeVFSResult result = GNOME_VFS_OK;
-	const gchar *msg;
-	EogCollectionView *view;
-	GtkWidget *dialog;
-
-	g_return_val_if_fail (EOG_IS_COLLECTION_VIEW (user_data), FALSE);
-	view = EOG_COLLECTION_VIEW (user_data);
-
-	/* If the image isn't selected, do nothing */
-	if (!cimage_is_selected (image))
-		return (TRUE);
-
-	uri = cimage_get_uri (image);
-	result = gnome_vfs_find_directory (uri,
-					GNOME_VFS_DIRECTORY_KIND_TRASH,
-					&trash, FALSE, FALSE, 0777);
-	if (result == GNOME_VFS_OK) {
-		path = gnome_vfs_uri_append_file_name (trash, 
-				gnome_vfs_uri_get_path (uri));
-		gnome_vfs_uri_unref (trash);
-		result = gnome_vfs_move_uri (uri, path, TRUE);
-		gnome_vfs_uri_unref (path);
-		if (result == GNOME_VFS_OK)
-			eog_collection_model_remove_item (model, cimage_get_unique_id (image));
-	}
-	gnome_vfs_uri_unref (uri);
-
-	if (result != GNOME_VFS_OK) {
-		msg = gnome_vfs_result_to_string (result);
-
-		dialog = gtk_message_dialog_new (
-			NULL, GTK_DIALOG_MODAL,
-			GTK_MESSAGE_ERROR,
-			GTK_BUTTONS_CLOSE,
-			msg);
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-		
-		return (FALSE);
-	}
-	
-	return (TRUE);
-}
-
-static void
-handle_delete_activate (GtkMenuItem *item, EogCollectionView *view)
-{
-	g_return_if_fail (EOG_IS_COLLECTION_VIEW (view));
-	
-	eog_collection_model_foreach (view->priv->model, delete_item, view);
-}
-
-#ifdef ENABLE_EVOLUTION
-static gboolean
-send_item (EogCollectionModel *model, guint n, gpointer user_data)
-{
-	Bonobo_StorageInfo *info;
-	Bonobo_Stream stream;
-	Bonobo_Stream_iobuf *buffer;
-	CORBA_Object composer;
-	GNOME_Evolution_Composer_AttachmentData *attachment_data;
-	CORBA_Environment ev;
-	gchar *uri;
-	CImage *image;
-
-	g_return_val_if_fail (EOG_IS_COLLECTION_MODEL (model), FALSE);
-	composer = user_data;
-
-	image = eog_collection_model_get_image (model, n);
-	
-	/* If the image isn't selected, do nothing */
-	if (!cimage_is_selected (image))
-		return (TRUE);
-
-	CORBA_exception_init (&ev);
-
-	uri = eog_collection_model_get_uri (model, n);
-	stream = bonobo_get_object (uri, "IDL:Bonobo/Stream:1.0", &ev);
-	g_free (uri);
-	if (BONOBO_EX (&ev)) {
-		g_warning ("Could not load file: %s",
-			   bonobo_exception_get_text (&ev));
-		return (FALSE);
-	}
-
-	info = Bonobo_Stream_getInfo (stream, Bonobo_FIELD_CONTENT_TYPE |
-					      Bonobo_FIELD_SIZE, &ev);
-	if (BONOBO_EX (&ev)) {
-		bonobo_object_release_unref (stream, NULL);
-		g_warning ("Could not get info about stream: %s",
-			   bonobo_exception_get_text (&ev));
-		return (FALSE);
-	}
-
-	Bonobo_Stream_read (stream, info->size, &buffer, &ev);
-	bonobo_object_release_unref (stream, NULL);
-	if (BONOBO_EX (&ev)) {
-		CORBA_free (info);
-		g_warning ("Could not read stream: %s",
-			   bonobo_exception_get_text (&ev));
-		return (FALSE);
-	}
-
-	attachment_data = GNOME_Evolution_Composer_AttachmentData__alloc ();
-	attachment_data->_buffer = buffer->_buffer;
-	attachment_data->_length = buffer->_length;
-	GNOME_Evolution_Composer_attachData (composer, info->content_type,
-					     info->name, info->name, FALSE,
-					     attachment_data, &ev);
-	CORBA_free (info);
-	CORBA_free (attachment_data);
-	if (BONOBO_EX (&ev)) {
-		g_warning ("Unable to attach image: %s", 
-			   bonobo_exception_get_text (&ev));
-		CORBA_exception_free (&ev);
-		return (FALSE);
-	}
-	
-	CORBA_exception_free (&ev);
-
-	return (TRUE);
-}
-
-static void
-handle_send_activate (GtkMenuItem *item, EogCollectionView *view)
-{
-	CORBA_Object composer;
-	CORBA_Environment ev;
-
-	g_return_if_fail (EOG_IS_COLLECTION_VIEW (view));
-
-	CORBA_exception_init (&ev);
-	composer = oaf_activate_from_id ("OAFIID:GNOME_Evolution_Mail_Composer",
-					 0, NULL, &ev);
-	if (BONOBO_EX (&ev)) {
-		g_warning ("Unable to start composer: %s",
-			   bonobo_exception_get_text (&ev));
-		CORBA_exception_free (&ev);
-		return;
-	}
-
-	eog_collection_model_foreach (view->priv->model, send_item, composer);
-
-	GNOME_Evolution_Composer_show (composer, &ev);
-	if (BONOBO_EX (&ev)) {
-		g_warning ("Unable to show composer: %s", 
-			   bonobo_exception_get_text (&ev));
-		CORBA_exception_free (&ev);
-		bonobo_object_release_unref (composer, NULL);
-		return;
-	}
-
-	CORBA_exception_free (&ev);
-}
-#endif
-
 static void
 kill_popup_menu (GtkWidget *widget, GtkMenu *menu)
 {
@@ -477,6 +387,7 @@ static gboolean
 handle_right_click (EogWrapList *wlist, gint n, GdkEvent *event, 
 		    EogCollectionView *view)
 {
+#if 0
 	GtkWidget *menu, *item, *label;
 
 	g_return_val_if_fail (EOG_IS_COLLECTION_VIEW (view), FALSE);
@@ -485,18 +396,6 @@ handle_right_click (EogWrapList *wlist, gint n, GdkEvent *event,
 	g_signal_connect (G_OBJECT (menu), "hide",
 			  G_CALLBACK (kill_popup_menu), menu);
 
-#ifdef ENABLE_EVOLUTION
-	label = gtk_label_new (_("Send"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_widget_show (label);
-
-	item = gtk_menu_item_new ();
-	gtk_widget_show (item);
-	g_signal_connect (G_OBJECT (item), "activate",
-			  G_CALLBACK (handle_send_activate), view);
-	gtk_container_add (GTK_CONTAINER (item), label);
-	gtk_menu_append (GTK_MENU (menu), item);
-#endif
 
 	label = gtk_label_new (_("Move to Trash"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
@@ -513,6 +412,9 @@ handle_right_click (EogWrapList *wlist, gint n, GdkEvent *event,
 			event->button.button, event->button.time);
 
 	return (TRUE);
+#else
+	return FALSE;
+#endif
 }
 
 static void
@@ -541,7 +443,7 @@ eog_collection_view_get_prop (BonoboPropertyBag *bag,
 		if (base_uri == NULL)
 			title = g_strdup (_("Collection View"));
 		else {
-			if (g_ascii_strncasecmp ("file:", base_uri, 5) == 0)
+			if (g_strncasecmp ("file:", base_uri, 5) == 0)
 				title = g_strdup ((base_uri+5*sizeof(guchar)));
 			else
 				title = g_strdup (base_uri);
@@ -556,31 +458,11 @@ eog_collection_view_get_prop (BonoboPropertyBag *bag,
 		gint nimg, nsel;
 			
 		nimg = eog_collection_model_get_length (priv->model);
-		nsel = eog_collection_model_get_selected_length (priv->model);
+		nsel = eog_wrap_list_get_n_selected (EOG_WRAP_LIST (priv->wraplist));
 
 		str = g_new0 (guchar, 70);
 
-		if (nsel == 0)
-			g_snprintf (str, 70, "Images: %i", nimg);
-		else if (nsel == 1) {
-			CImage *img; 
-			GnomeVFSURI *uri;
-			gchar *basename;
-
-			img = eog_collection_model_get_selected_image (priv->model);
-			uri = cimage_get_uri (img);
-			g_assert (uri != NULL);
-
-			basename = g_path_get_basename (gnome_vfs_uri_get_path (uri));
-			g_snprintf (str, 70, "Images: %i  %s (%i x %i)", nimg,
-				    basename,
-				    cimage_get_width (img),
-				    cimage_get_height (img));
-
-			gnome_vfs_uri_unref (uri);
-			g_free (basename);
-		} else
-			g_snprintf (str, 70, "Images: %i  Selected: %i", nimg, nsel);
+		g_snprintf (str, 70, "Images: %i/%i", nsel, nimg);
 	       
 		BONOBO_ARG_SET_STRING (arg, str);
 		g_free (str);
@@ -631,7 +513,6 @@ update_properties (EogCollectionView *view)
 						      p, NULL,
 						      view);
 		
-			g_print ("notify %s listners.\n", property_name[p]);
 			bonobo_event_source_notify_listeners (priv->property_bag->es,
 							      property_name[p],
 							      arg, NULL);
@@ -663,6 +544,30 @@ update_title_text (EogCollectionView *view)
 	}	
 }
 
+static void
+handle_selection_changed (EogWrapList *list, EogCollectionView *view)
+{
+	EogImage *image;
+	EogCollectionViewPrivate *priv;
+
+	image = eog_wrap_list_get_first_selected_image (list);
+
+	priv = view->priv;
+
+	if (priv->displayed_image != NULL) {
+		eog_image_free_mem (priv->displayed_image);
+		g_object_unref (priv->displayed_image);
+		priv->displayed_image = NULL;
+	}
+
+	eog_scroll_view_set_image (EOG_SCROLL_VIEW (priv->scroll_view), image);
+	eog_info_view_set_image (EOG_INFO_VIEW (priv->info_view), image);
+
+	priv->displayed_image = image;
+	
+	update_status_text (view);
+}
+
 static void
 model_size_changed (EogCollectionModel *model, GList *id_list,  gpointer data)
 {
@@ -675,17 +580,6 @@ model_size_changed (EogCollectionModel *model, GList *id_list,  gpointer data)
 	update_status_text (view);
 }
 
-static void
-model_selection_changed (EogCollectionModel *model, GQuark id, gpointer data)
-{
-	EogCollectionView *view;
-
-	g_return_if_fail (data != NULL);
-	g_return_if_fail (EOG_IS_COLLECTION_VIEW (data));
-
-	view = EOG_COLLECTION_VIEW (data);
-	update_status_text (view);
-}
 
 static void
 model_base_uri_changed (EogCollectionModel *model, gpointer data)
@@ -718,36 +612,72 @@ layout_changed_cb (GConfClient *client, guint cnxn_id,
 }
 
 static void
-color_changed_cb (GConfClient *client, guint cnxn_id, 
-		   GConfEntry *entry, gpointer user_data)
+zoomable_set_frame_cb (BonoboZoomable *zoomable, EogCollectionView *view)
+{
+	g_return_if_fail (EOG_IS_COLLECTION_VIEW (view));
+
+	view->priv->has_zoomable_frame = TRUE;
+}
+
+static void
+zoomable_set_zoom_level_cb (BonoboZoomable *zoomable, CORBA_float new_zoom_level,
+			    EogCollectionView *view)
+{
+	g_return_if_fail (EOG_IS_COLLECTION_VIEW (view));
+
+	eog_scroll_view_set_zoom (EOG_SCROLL_VIEW (view->priv->scroll_view), new_zoom_level);
+}
+
+static void
+zoomable_zoom_in_cb (BonoboZoomable *zoomable, EogCollectionView *view)
+{
+	g_return_if_fail (EOG_IS_COLLECTION_VIEW (view));
+
+	eog_scroll_view_zoom_in (EOG_SCROLL_VIEW (view->priv->scroll_view), FALSE);
+}
+
+static void
+zoomable_zoom_out_cb (BonoboZoomable *zoomable, EogCollectionView *view)
+{
+	g_return_if_fail (EOG_IS_COLLECTION_VIEW (view));
+
+	eog_scroll_view_zoom_out (EOG_SCROLL_VIEW (view->priv->scroll_view), FALSE);
+}
+
+static void
+zoomable_zoom_to_fit_cb (BonoboZoomable *zoomable, EogCollectionView *view)
+{
+	g_return_if_fail (EOG_IS_COLLECTION_VIEW (view));
+
+	eog_scroll_view_zoom_fit (EOG_SCROLL_VIEW (view->priv->scroll_view));
+}
+
+static void
+zoomable_zoom_to_default_cb (BonoboZoomable *zoomable, EogCollectionView *view)
+{
+	g_return_if_fail (EOG_IS_COLLECTION_VIEW (view));
+
+	eog_scroll_view_set_zoom (EOG_SCROLL_VIEW (view->priv->scroll_view), 1.0);
+}
+
+static void
+view_zoom_changed_cb (GtkWidget *widget, double zoom, gpointer data)
 {
 	EogCollectionView *view;
-	GdkColor color;
-	GSList *l = NULL;
+	EogCollectionViewPrivate *priv;
 
-	g_return_if_fail (user_data != NULL);
-	g_return_if_fail (EOG_IS_COLLECTION_VIEW (user_data));
-	g_return_if_fail (entry->value->type == GCONF_VALUE_LIST);
+	view = EOG_COLLECTION_VIEW (data);
+	priv = view->priv;
 
-	view = EOG_COLLECTION_VIEW (user_data);
-	
-	g_assert (gconf_value_get_list_type (entry->value) == GCONF_VALUE_INT);
-	
-	l = gconf_client_get_list (client, pref_key[PREF_COLOR],
-					   GCONF_VALUE_INT, NULL);
-	
-	color.red = GPOINTER_TO_UINT (l->data);
-	color.green = GPOINTER_TO_UINT (l->next->data);
-	color.blue = GPOINTER_TO_UINT (l->next->next->data);
-
-	eog_wrap_list_set_background_color (EOG_WRAP_LIST (view->priv->wraplist),
-					    &color);
+	/* inform zoom interface listeners */
+	bonobo_zoomable_report_zoom_level_changed (priv->zoomable, zoom, NULL);
 }
 
 /* read configuration */
 static void
-set_configuration_values (EogCollectionView *view)
+init_gconf_defaults (EogCollectionView *view)
 {
+#if 0
 	EogCollectionViewPrivate *priv = NULL;
 	gint layout;
 	GSList *l;
@@ -757,73 +687,6 @@ set_configuration_values (EogCollectionView *view)
 	g_return_if_fail (EOG_IS_COLLECTION_VIEW (view));
 	
 	priv = view->priv;
-	
-	/* set layout mode */
-	layout = gconf_client_get_int (priv->client, 
-				       pref_key[PREF_LAYOUT],
-				       NULL);
-	eog_wrap_list_set_layout_mode (EOG_WRAP_LIST (priv->wraplist),
-				       layout);
-	
-	/* set background color */
-	l = gconf_client_get_list (priv->client, pref_key[PREF_COLOR],
-				   GCONF_VALUE_INT, NULL);
-	if (l) {
-		color.red = GPOINTER_TO_UINT (l->data);
-		color.green = GPOINTER_TO_UINT (l->next->data);
-		color.blue = GPOINTER_TO_UINT (l->next->next->data);
-	} else {
-		color.red = 57015;   /* default gtk color */
-		color.green = 57015;
-		color.blue = 57015;
-	}
-	eog_wrap_list_set_background_color (EOG_WRAP_LIST (priv->wraplist),
-					    &color);
-	/* add configuration listeners */
-	priv->notify_id[PREF_LAYOUT] = 
-		gconf_client_notify_add (priv->client, 
-					 pref_key[PREF_LAYOUT],
-					 layout_changed_cb,
-					 view,
-					 NULL, NULL);
-	priv->notify_id[PREF_COLOR] = 
-		gconf_client_notify_add (priv->client, 
-					 pref_key[PREF_COLOR],
-					 color_changed_cb,
-					 view,
-					 NULL, NULL);
-}
-
-static gint
-load_uri_cb (BonoboPersistFile *pf, const CORBA_char *text_uri,
-	     CORBA_Environment *ev, void *closure)
-{
-	EogCollectionViewPrivate *priv;
-	
-	priv = EOG_COLLECTION_VIEW (closure)->priv;
-
-	if (text_uri == CORBA_OBJECT_NIL) return FALSE;
-
-	eog_collection_model_set_uri (priv->model, (gchar*)text_uri); 
-
-	return TRUE;
-}
-
-
-EogCollectionView *
-eog_collection_view_construct (EogCollectionView *list_view)
-{
-	EogCollectionViewPrivate *priv = NULL;
-	EogItemFactory *factory;
-	EogImageLoader *loader;
-	BonoboPersistFile *persist_file;
-
-	g_return_val_if_fail (list_view != NULL, NULL);
-	g_return_val_if_fail (EOG_IS_COLLECTION_VIEW (list_view), NULL);
-	
-	priv = list_view->priv;
-	
-	priv->uic = bonobo_ui_component_new ("EogCollectionView");
 
 	/* Make sure GConf is initialized */
 	if (!gconf_is_initialized ())
@@ -832,70 +695,223 @@ eog_collection_view_construct (EogCollectionView *list_view)
 	priv->client = gconf_client_get_default ();
 	gconf_client_add_dir (priv->client, PREF_PREFIX, 
 			      GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-
-	/* construct widget */
-	g_assert (EOG_IS_COLLECTION_VIEW (list_view));
-	priv->model = eog_collection_model_new ();
-	g_signal_connect (G_OBJECT (priv->model), "image-added", 
-			  G_CALLBACK (model_size_changed),
-			  list_view);
-	g_signal_connect (G_OBJECT (priv->model), "image-removed", 
-			  G_CALLBACK (model_size_changed),
-			  list_view);
-	g_signal_connect (G_OBJECT (priv->model), "selection-changed",
-			  G_CALLBACK (model_selection_changed),
-			  list_view);
-	g_signal_connect (G_OBJECT (priv->model), "base-uri-changed",
-			  G_CALLBACK (model_base_uri_changed),
-			  list_view);
-
-#if HAVE_LIBPREVIEW
-	loader = eog_image_loader_preview_new (96, 96);
-#else
-	loader = eog_image_loader_simple_new (96, 96);
+	
+	/* set layout mode */
+	layout = gconf_client_get_int (priv->client, 
+				       pref_key[PREF_LAYOUT],
+				       NULL);
+	eog_wrap_list_set_layout_mode (EOG_WRAP_LIST (priv->wraplist),
+				       layout);
+	
+	/* add configuration listeners */
+	priv->notify_id[PREF_LAYOUT] = 
+		gconf_client_notify_add (priv->client, 
+					 pref_key[PREF_LAYOUT],
+					 layout_changed_cb,
+					 view,
+					 NULL, NULL);
 #endif
-	factory = EOG_ITEM_FACTORY (eog_item_factory_clean_new (loader));
+}
 
-	priv->root = gtk_scrolled_window_new (NULL, NULL);
+static gint
+load_uri_cb (BonoboPersistFile *pf, const CORBA_char *text_uri,
+	     CORBA_Environment *ev, void *closure)
+{
+	EogCollectionViewPrivate *priv;
+	EogCollectionView *view;
 
+	view = EOG_COLLECTION_VIEW (closure);
+	priv = view->priv;
+
+	if (text_uri == CORBA_OBJECT_NIL) return 0;
+
+	if (priv->model == NULL) {
+		priv->model = eog_collection_model_new ();
+		eog_wrap_list_set_model (EOG_WRAP_LIST (priv->wraplist), priv->model);
+
+		/* construct widget */
+#if 0
+		g_signal_connect (G_OBJECT (priv->model), "image-added", 
+				  G_CALLBACK (model_size_changed),
+				  list_view);
+		g_signal_connect (G_OBJECT (priv->model), "image-removed", 
+				  G_CALLBACK (model_size_changed),
+				  list_view);
+		g_signal_connect (G_OBJECT (priv->model), "selection-changed",
+				  G_CALLBACK (model_selection_changed),
+				  list_view);
+		g_signal_connect (G_OBJECT (priv->model), "base-uri-changed",
+				  G_CALLBACK (model_base_uri_changed),
+				  list_view);
+#endif
+
+	}
+
+	g_print ("load_uri_cb: %s\n", (char*) text_uri);
+
+	eog_collection_model_add_uri (priv->model, (gchar*)text_uri); 
+
+	return 0;
+}
+
+static GtkWidget*
+create_user_interface (EogCollectionView *list_view)
+{
+	EogCollectionViewPrivate *priv;
+	GtkWidget *hpaned;
+	GtkWidget *vpaned;
+	GtkWidget *sw;
+	GtkWidget *frame;
+	
+	priv = list_view->priv;
+
+	/* the image view for the full size image */
+ 	priv->scroll_view = eog_scroll_view_new ();
+	g_object_set (G_OBJECT (priv->scroll_view), "height_request", 250, NULL);
+	g_signal_connect (G_OBJECT (priv->scroll_view),
+			  "zoom_changed",
+			  (GCallback) view_zoom_changed_cb,
+			  list_view);
+	frame = gtk_widget_new (GTK_TYPE_FRAME, "shadow-type", GTK_SHADOW_IN, NULL);
+	gtk_container_add (GTK_CONTAINER (frame), priv->scroll_view);
+
+	/* info view for additional image information */
+	priv->info_view = gtk_widget_new (EOG_TYPE_INFO_VIEW, NULL);
+	sw = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), 
+					GTK_POLICY_AUTOMATIC,
+					GTK_POLICY_AUTOMATIC);
+	gtk_container_add (GTK_CONTAINER (sw), priv->info_view);
+
+	hpaned = gtk_hpaned_new ();
+	gtk_paned_pack1 (GTK_PANED (hpaned), frame, TRUE, TRUE);
+	gtk_paned_pack2 (GTK_PANED (hpaned), sw, FALSE, TRUE);
+	gtk_widget_show_all (hpaned);
+
+#if !HAVE_EXIF
+	gtk_paned_set_position (GTK_PANED (hpaned), 10000);
+#endif
+
+	/* the wrap list for all the thumbnails */
 	priv->wraplist = eog_wrap_list_new ();
-	gtk_container_add (GTK_CONTAINER (priv->root), priv->wraplist);
-	eog_wrap_list_set_model (EOG_WRAP_LIST (priv->wraplist), priv->model);
-	eog_wrap_list_set_factory (EOG_WRAP_LIST (priv->wraplist), factory);
+	g_object_set (G_OBJECT (priv->wraplist), 
+		      "height_request", 200, 
+		      "width_request", 500,
+		      NULL);
 	eog_wrap_list_set_col_spacing (EOG_WRAP_LIST (priv->wraplist), 20);
 	eog_wrap_list_set_row_spacing (EOG_WRAP_LIST (priv->wraplist), 20);
-	g_signal_connect (G_OBJECT (priv->wraplist), "double_click", 
-			  G_CALLBACK (handle_double_click), list_view);
-	g_signal_connect (G_OBJECT (priv->wraplist), "right_click",
-			  G_CALLBACK (handle_right_click), list_view);
+	g_signal_connect (G_OBJECT (priv->wraplist), "selection_changed",
+			  G_CALLBACK (handle_selection_changed), list_view);
 
-	gtk_widget_show (priv->wraplist);
-	gtk_widget_show (priv->root);
+	sw = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
+	gtk_container_add (GTK_CONTAINER (sw), priv->wraplist);
+	gtk_widget_show_all (sw);
 
-	g_object_unref (G_OBJECT (factory));
-	g_object_unref (G_OBJECT (loader));
+	/* put it all together */
+	vpaned = gtk_vpaned_new ();
+	
+	gtk_paned_pack1 (GTK_PANED (vpaned), hpaned, TRUE, TRUE);
+	gtk_paned_pack2 (GTK_PANED (vpaned), sw, TRUE, TRUE);
+
+	/* by default make the wrap list keyboard active */
+	gtk_widget_grab_focus (priv->wraplist);
+
+	gtk_widget_show (vpaned);
+
+	return vpaned;
+}
+
+
+static EogCollectionView *
+eog_collection_view_construct (EogCollectionView *list_view)
+{
+	EogCollectionViewPrivate *priv = NULL;
+	BonoboControl *control;
+	GtkWidget *root;
+	BonoboZoomable *zoomable;
+
+	g_return_val_if_fail (list_view != NULL, NULL);
+	g_return_val_if_fail (EOG_IS_COLLECTION_VIEW (list_view), NULL);
+	
+	priv = list_view->priv;
+	
+	root = create_user_interface (list_view);
+
+	bonobo_persist_file_construct (BONOBO_PERSIST_FILE (list_view),
+				       load_uri_cb, NULL,
+				       "OAFIID:GNOME_EOG_CollectionControl",
+				       list_view);
+
+	/* interface Bonobo::Control */
+	control = bonobo_control_new (root);
+	g_signal_connect (control, "activate", G_CALLBACK (control_activate_cb), list_view);
 
-	/* add persist file interface */
-	persist_file = bonobo_persist_file_new (load_uri_cb, NULL,
-						"OAFIID:GNOME_EOG_CollectionControl",
-						list_view);
 	bonobo_object_add_interface (BONOBO_OBJECT (list_view),
-				     BONOBO_OBJECT (persist_file));
+				     BONOBO_OBJECT (control));
+
+
+	/* Interface Bonobo::Zoomable */
+	zoomable = bonobo_zoomable_new ();
+	priv->zoomable = zoomable;
+
+	g_signal_connect (G_OBJECT (zoomable),
+			  "set_frame",
+			  G_CALLBACK (zoomable_set_frame_cb),
+			  list_view);
+	g_signal_connect (G_OBJECT (zoomable),
+			  "set_zoom_level",
+			  G_CALLBACK (zoomable_set_zoom_level_cb),
+			  list_view);
+	g_signal_connect (G_OBJECT (zoomable),
+			  "zoom_in",
+			  G_CALLBACK (zoomable_zoom_in_cb),
+			  list_view);
+	g_signal_connect (G_OBJECT (zoomable),
+			  "zoom_out",
+			  G_CALLBACK (zoomable_zoom_out_cb),
+			  list_view);
+	g_signal_connect (G_OBJECT (zoomable),
+			  "zoom_to_fit",
+			  G_CALLBACK (zoomable_zoom_to_fit_cb),
+			  list_view);
+	g_signal_connect (G_OBJECT (zoomable),
+			  "zoom_to_default",
+			  G_CALLBACK (zoomable_zoom_to_default_cb),
+			  list_view);
+
+	bonobo_zoomable_set_parameters (zoomable,
+					1.0,   /* current */
+					0.01,  /* min */
+					20.0,  /* max */
+					TRUE,
+					TRUE);
+
+	bonobo_object_add_interface (BONOBO_OBJECT (list_view),
+				     BONOBO_OBJECT (zoomable));
 
 
 	/* Property Bag */
 	priv->property_bag = bonobo_property_bag_new (eog_collection_view_get_prop,
 						      eog_collection_view_set_prop,
 						      list_view);
-	bonobo_property_bag_add (priv->property_bag, property_name[0], PROP_WINDOW_TITLE,
+	bonobo_property_bag_add (priv->property_bag, property_name[PROP_WINDOW_TITLE], PROP_WINDOW_TITLE,
 				 BONOBO_ARG_STRING, NULL, _("Window Title"),
 				 BONOBO_PROPERTY_READABLE);
-	bonobo_property_bag_add (priv->property_bag, property_name[1], PROP_WINDOW_STATUS,
+	bonobo_property_bag_add (priv->property_bag, property_name[PROP_WINDOW_STATUS], PROP_WINDOW_STATUS,
 				 BONOBO_ARG_STRING, NULL, _("Status Text"),
 				 BONOBO_PROPERTY_READABLE);
-
+	bonobo_control_set_properties (BONOBO_CONTROL (control), 
+				       BONOBO_OBJREF (priv->property_bag),
+				       NULL);
+	
 	/* read user defined configuration */
-	set_configuration_values (list_view);
+	init_gconf_defaults (list_view);
+
+	/* UI Component */
+	priv->uic = bonobo_ui_component_new ("EogCollectionView");
+
+	bonobo_object_dump_interfaces (BONOBO_OBJECT (list_view));
 
 	return list_view;
 }
@@ -911,13 +927,3 @@ eog_collection_view_new (void)
 	return eog_collection_view_construct (list_view);
 }
 
-BonoboPropertyBag*
-eog_collection_view_get_property_bag (EogCollectionView *view)
-{
-	g_return_val_if_fail (view != NULL, NULL);
-	g_return_val_if_fail (EOG_IS_COLLECTION_VIEW (view), NULL);
-
-	bonobo_object_ref (BONOBO_OBJECT (view->priv->property_bag));
-
-	return view->priv->property_bag;
-}
