@@ -94,6 +94,9 @@ static int n_active_images = 0;
 
 #define CHECK_LOAD_TIMEOUT 5
 
+/* Chunk size for reading image data */
+#define READ_BUFFER_SIZE 65536
+
 /*============================================
 
   static thumbnail loader for all image objects
@@ -473,7 +476,7 @@ eog_image_instance_init (EogImage *img)
 }
 
 EogImage* 
-eog_image_new_uri (GnomeVFSURI *uri, EogImageLoadMode mode)
+eog_image_new_uri (GnomeVFSURI *uri)
 {
 	EogImage *img;
 	EogImagePrivate *priv;
@@ -482,7 +485,7 @@ eog_image_new_uri (GnomeVFSURI *uri, EogImageLoadMode mode)
 	priv = img->priv;
 
 	priv->uri = gnome_vfs_uri_ref (uri);
-	priv->mode = mode;
+	priv->mode = EOG_IMAGE_LOAD_DEFAULT;
 	priv->modified = FALSE;
 	priv->load_thread = NULL;
 
@@ -495,13 +498,13 @@ eog_image_new_uri (GnomeVFSURI *uri, EogImageLoadMode mode)
 }
 
 EogImage* 
-eog_image_new (const char *txt_uri, EogImageLoadMode mode)
+eog_image_new (const char *txt_uri)
 {
 	GnomeVFSURI *uri;
 	EogImage *image;
 
 	uri = gnome_vfs_uri_new (txt_uri);
-	image = eog_image_new_uri (uri, mode);
+	image = eog_image_new_uri (uri);
 	gnome_vfs_uri_unref (uri);
 
 	return image;
@@ -774,6 +777,7 @@ real_image_load (gpointer data)
 	guchar *buffer;
 	GnomeVFSFileSize bytes_read;
 	gboolean failed;
+	GError *error = NULL;
 #if HAVE_EXIF
 	ExifLoaderData *eld;
 #endif
@@ -787,7 +791,10 @@ real_image_load (gpointer data)
 
 	g_assert (priv->image == NULL);
 #if HAVE_EXIF
-	g_assert (priv->exif == NULL);
+	if (priv->exif != NULL) {
+		/* FIXME: this shouldn't happen but do so sometimes. */
+		g_warning ("exif data not freed\n");
+	}
 #endif
 
 	result = gnome_vfs_open_uri (&handle, priv->uri, GNOME_VFS_OPEN_READ);
@@ -800,7 +807,7 @@ real_image_load (gpointer data)
 		return NULL;
 	}
 	
-	buffer = g_new0 (guchar, 4096);
+	buffer = g_new0 (guchar, READ_BUFFER_SIZE);
 	loader = gdk_pixbuf_loader_new ();
 	failed = FALSE;
 #if HAVE_EXIF
@@ -814,7 +821,7 @@ real_image_load (gpointer data)
 	}
 	
 	while (!priv->cancel_loading) {
-		result = gnome_vfs_read (handle, buffer, 4096, &bytes_read);
+		result = gnome_vfs_read (handle, buffer, READ_BUFFER_SIZE, &bytes_read);
 		if (result == GNOME_VFS_ERROR_EOF || bytes_read == 0) {
 			break;
 		}
@@ -823,12 +830,12 @@ real_image_load (gpointer data)
 			break;
 		}
 		
-		if (!gdk_pixbuf_loader_write (loader, buffer, bytes_read, NULL)) {
+		if (!gdk_pixbuf_loader_write (loader, buffer, bytes_read, &error)) {
 			failed = TRUE;
 			break;
 		}
 #if HAVE_EXIF
-		if (exif_loader_write (eld, buffer, 4096)) {
+		if (exif_loader_write (eld, buffer, bytes_read)) {
 			g_mutex_lock (img->priv->status_mutex);
 			exif_data_ref (eld->data);
 			priv->exif = eld->data;
@@ -838,6 +845,8 @@ real_image_load (gpointer data)
 #endif
 	}
 
+	gdk_pixbuf_loader_close (loader, NULL);	
+
 	g_free (buffer);
 	gnome_vfs_close (handle);
 	
@@ -849,7 +858,13 @@ real_image_load (gpointer data)
 			priv->image = NULL;
 		}
 		priv->load_status |= EOG_IMAGE_LOAD_STATUS_FAILED;
-		priv->error_message = NULL; /* FIXME: add descriptive error message */
+		
+		if (error != NULL) {
+			priv->error_message = g_strdup (error->message);
+		}
+		else {
+			priv->error_message = NULL;
+		}
 	}
 	else if (priv->cancel_loading) {
 		if (priv->image != NULL) {
@@ -863,13 +878,13 @@ real_image_load (gpointer data)
 	else {
 		if (priv->image == NULL) {
 			priv->image = gdk_pixbuf_loader_get_pixbuf (loader);
+			g_assert (priv->image != NULL);
 			g_object_ref (priv->image);
 
 			priv->width = gdk_pixbuf_get_width (priv->image);
 			priv->height = gdk_pixbuf_get_height (priv->image);
 			priv->load_status |= EOG_IMAGE_LOAD_STATUS_PREPARED;
 		}
-
 		priv->load_status |= EOG_IMAGE_LOAD_STATUS_DONE;
 	}
 
@@ -884,31 +899,56 @@ real_image_load (gpointer data)
 	priv->load_thread = NULL;
 	g_mutex_unlock (priv->status_mutex);
 	
-	gdk_pixbuf_loader_close (loader, NULL);	
+	if (error != NULL) {
+		g_error_free (error);
+	}
 	g_object_unref (loader);
 
 	return NULL;
 }
 
-gboolean 
-eog_image_load (EogImage *img)
+void
+eog_image_load (EogImage *img, EogImageLoadMode mode)
 {
 	EogImagePrivate *priv;
 	gboolean image_loaded;
 	gboolean thread_running;
 
+	g_return_if_fail (EOG_IS_IMAGE (img));
+
 	priv = EOG_IMAGE (img)->priv;
 
-	g_return_val_if_fail (priv->uri != NULL, FALSE);
+	g_return_if_fail (priv->uri != NULL);
 
 	g_mutex_lock (priv->status_mutex);
 	image_loaded = priv->image != NULL;
 	thread_running = priv->load_thread != NULL;
 	g_mutex_unlock (priv->status_mutex);
 
-	if (!image_loaded && !thread_running)
-	{
+	if (image_loaded && !thread_running) {
+		g_assert (priv->image != NULL);
+		g_signal_emit (G_OBJECT (img), eog_image_signals [SIGNAL_LOADING_FINISHED], 0);
+		g_signal_emit (G_OBJECT (img), eog_image_signals [SIGNAL_LOADING_INFO_FINISHED], 0);
+	}
+	else if (!image_loaded && !thread_running) { 
+                /* we assume that in all other cases there is no image loaded */
+		g_assert (priv->image == NULL);
+		
+                /* make sure the object isn't destroyed while we try to load it */
+		g_object_ref (img);
+
+		/* initialize data fields for progressive loading */
+		priv->load_status = EOG_IMAGE_LOAD_STATUS_NONE;
+		priv->update_x1 = 10000;
+		priv->update_y1 = 10000;
+		priv->update_x2 = 0;
+		priv->update_y2 = 0;
+		priv->error_message = NULL;
+		priv->cancel_loading = FALSE;
+		priv->mode = mode;
+
 		if (priv->mode == EOG_IMAGE_LOAD_DEFAULT) {
+			/* determine if the image should be loaded progressively or not */
 			if (gnome_vfs_uri_is_local (priv->uri)) {
 				GnomeVFSFileInfo *info;
 				GnomeVFSResult result;
@@ -922,7 +962,7 @@ eog_image_load (EogImage *img)
 					g_signal_emit (G_OBJECT (img), eog_image_signals [SIGNAL_LOADING_FAILED], 
 						       0, gnome_vfs_result_to_string (result));
 					g_print ("VFS Error: %s\n", gnome_vfs_result_to_string (result));
-					return FALSE;
+					return;
 				}
 
 				priv->mode = EOG_IMAGE_LOAD_PROGRESSIVE;
@@ -936,22 +976,15 @@ eog_image_load (EogImage *img)
 			}
 			else {
 				priv->mode = EOG_IMAGE_LOAD_PROGRESSIVE;
+				
 			}
 		}
-		
-		g_object_ref (img); /* make sure the object isn't destroyed while we try to load it */
-		priv->load_status = EOG_IMAGE_LOAD_STATUS_NONE;
-		priv->update_x1 = 10000;
-		priv->update_y1 = 10000;
-		priv->update_x2 = 0;
-		priv->update_y2 = 0;
-		priv->error_message = NULL;
-		priv->cancel_loading = FALSE;
+
+		/* start the thread machinery */
 		priv->load_id = g_timeout_add (CHECK_LOAD_TIMEOUT, check_load_status, img);
 		priv->load_thread = g_thread_create (real_image_load, img, TRUE, NULL);
+		
 	}
-
-	return (image_loaded && !thread_running);
 }
 
 gboolean 
@@ -1219,6 +1252,8 @@ eog_image_free_mem (EogImage *img)
 		priv->exif = NULL;
 	}
 #endif
+
+	priv->load_status = EOG_IMAGE_LOAD_STATUS_NONE;
 }
 
 const gchar*        
@@ -1280,3 +1315,20 @@ eog_image_get_exif_information (EogImage *img)
 
 	return data;
 }
+
+gboolean            
+eog_image_is_loaded (EogImage *img)
+{
+	EogImagePrivate *priv;
+	gboolean result;
+
+	g_return_val_if_fail (EOG_IS_IMAGE (img), FALSE);
+
+	priv = img->priv;
+
+	g_mutex_lock (priv->status_mutex);
+	result = (priv->load_thread == NULL && priv->image != NULL);
+	g_mutex_unlock (priv->status_mutex);
+	
+	return result;
+}
